@@ -146,7 +146,7 @@ def recognize_all(
         skip_words = itertools.chain(skip_words, intents.skip_words)
 
     if skip_words:
-        text = _remove_skip_words(text, skip_words)
+        text = _remove_skip_words(text, skip_words, intents.settings.ignore_whitespace)
 
     if intents.settings.ignore_whitespace:
         text = WHITESPACE.sub("", text)
@@ -293,7 +293,7 @@ def is_match(
     text = normalize_text(text).strip()
 
     if skip_words:
-        text = _remove_skip_words(text, skip_words)
+        text = _remove_skip_words(text, skip_words, ignore_whitespace)
 
     if ignore_whitespace:
         text = WHITESPACE.sub("", text)
@@ -328,17 +328,24 @@ def is_match(
     return None
 
 
-def _remove_skip_words(text: str, skip_words: Iterable[str]) -> str:
+def _remove_skip_words(
+    text: str, skip_words: Iterable[str], ignore_whitespace: bool
+) -> str:
     """Remove skip words from text."""
 
     # It's critical that skip words are processed longest first, since they may
     # share prefixes.
     for skip_word in sorted(skip_words, key=len, reverse=True):
         skip_word = normalize_text(skip_word)
-        text = re.sub(rf"\b{re.escape(skip_word)}\b", "", text)
+        if ignore_whitespace:
+            text = text.replace(skip_word, "")
+        else:
+            # Use word boundaries
+            text = re.sub(rf"\b{re.escape(skip_word)}\b", "", text)
 
-    text = normalize_whitespace(text)
-    text = text.strip()
+    if not ignore_whitespace:
+        text = normalize_whitespace(text)
+        text = text.strip()
 
     return text
 
@@ -389,8 +396,14 @@ def match_expression(
             )
         else:
             # Remove punctuation and try again
-            context_text = PUNCTUATION.sub(" ", context.text).lstrip()
-            if context_text.startswith(chunk_text):
+            context_text = PUNCTUATION.sub("", context.text)
+            context_starts_with = context_text.startswith(chunk_text)
+            if (not context_starts_with) and context.is_start_of_word:
+                # Try stripping whitespace
+                context_text = context_text.lstrip()
+                context_starts_with = context_text.startswith(chunk_text)
+
+            if context_starts_with:
                 context_text = context_text[len(chunk_text) :]
                 yield MatchContext(
                     text=context_text,
